@@ -2,4 +2,4 @@ from ._api import HttpApi
 from ._header import Header
 from ._param import Param
 from ._query import Query
-from ._response import HttpResponse, JsonResponse
+from ._response import HttpResponse, JsonResponse, HtmlResponse
